{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2016-2020 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends "invenio_communities/details/settings/base.html" %}

{%- block javascript %}
{{ super() }}
{{ webpack['invenio-communities-privileges.js'] }}
{%- endblock javascript %}

{% set active_settings_menu_item = 'privileges' %}
{% set active_community_header_menu_item = 'settings' %}

{%- block settings_body %}
<div class="sixteen wide mobile sixteen wide tablet thirteen wide computer column">
  <div
    id="app"
    data-form-config='{{ form_config | tojson }}'
    data-community='{{ community | tojson}}'>
  </div>
</div>
{%- endblock settings_body %}
